camelot.camelot.model.memento

Package camelot :: Package camelot :: Package model :: Module memento |
[hide private]
[frames] | no frames]

# Module memento

source code

Set of classes to keep track of changes to objects and be able to restore their state

Classes | [hide private]
| Memento Keeps information on the previous state of objects, to keep track of changes and enable restore to that previous state
| BeforeUpdate The state of the object before an update took place
| BeforeDelete The state of the object before it is deleted
| Create Marks the creation of an object

Variables | [hide private]
| __metadata__ = `metadata`